pub struct Event {
pub origin_node: NodeId,
pub seq: SequenceNumber,
pub hlc: Hlc,
pub event_type: u32,
pub payload: Vec<u8>,
}Fields
origin_node: NodeIdseq: SequenceNumberhlc: Hlcevent_type: u32payload: Vec<u8>Trait Implementations
Sourceimpl Archive for Event
impl Archive for Event
Sourcetype Archived = ArchivedEvent
type Archived = ArchivedEvent
The archived representation of this type. Read more
Sourcetype Resolver = EventResolver
type Resolver = EventResolver
The resolver for this type. It must contain all the additional information from serializing
needed to make the archived type from the normal type.
Sourceimpl<__D: Fallible + ?Sized> Deserialize<Event, __D> for Archived<Event>where
NodeId: Archive,
Archived<NodeId>: Deserialize<NodeId, __D>,
SequenceNumber: Archive,
Archived<SequenceNumber>: Deserialize<SequenceNumber, __D>,
Hlc: Archive,
Archived<Hlc>: Deserialize<Hlc, __D>,
u32: Archive,
Archived<u32>: Deserialize<u32, __D>,
Vec<u8>: Archive,
Archived<Vec<u8>>: Deserialize<Vec<u8>, __D>,
impl<__D: Fallible + ?Sized> Deserialize<Event, __D> for Archived<Event>where
NodeId: Archive,
Archived<NodeId>: Deserialize<NodeId, __D>,
SequenceNumber: Archive,
Archived<SequenceNumber>: Deserialize<SequenceNumber, __D>,
Hlc: Archive,
Archived<Hlc>: Deserialize<Hlc, __D>,
u32: Archive,
Archived<u32>: Deserialize<u32, __D>,
Vec<u8>: Archive,
Archived<Vec<u8>>: Deserialize<Vec<u8>, __D>,