pub struct NodeId(pub u32);Tuple Fields
0: u32Trait Implementations
Sourceimpl Archive for NodeId
impl Archive for NodeId
Sourcetype Archived = ArchivedNodeId
type Archived = ArchivedNodeId
The archived representation of this type. Read more
Sourcetype Resolver = NodeIdResolver
type Resolver = NodeIdResolver
The resolver for this type. It must contain all the additional information from serializing
needed to make the archived type from the normal type.
impl Copy for NodeId
impl Eq for NodeId
Sourceimpl Ord for NodeId
impl Ord for NodeId
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for NodeId
impl PartialOrd for NodeId
impl StructuralPartialEq for NodeId