pub struct PeerSyncState {
pub known_vv: VersionVector,
pub last_acked: Option<SequenceNumber>,
}Fields
known_vv: VersionVectorlast_acked: Option<SequenceNumber>Trait Implementations
Sourceimpl Archive for PeerSyncState
impl Archive for PeerSyncState
Sourcetype Archived = ArchivedPeerSyncState
type Archived = ArchivedPeerSyncState
The archived representation of this type. Read more
Sourcetype Resolver = PeerSyncStateResolver
type Resolver = PeerSyncStateResolver
The resolver for this type. It must contain all the additional information from serializing
needed to make the archived type from the normal type.
Sourceimpl Clone for PeerSyncState
impl Clone for PeerSyncState
Sourcefn clone(&self) -> PeerSyncState
fn clone(&self) -> PeerSyncState
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PeerSyncState
impl Debug for PeerSyncState
Sourceimpl Default for PeerSyncState
impl Default for PeerSyncState
Sourcefn default() -> PeerSyncState
fn default() -> PeerSyncState
Returns the “default value” for a type. Read more
Sourceimpl<__D: Fallible + ?Sized> Deserialize<PeerSyncState, __D> for Archived<PeerSyncState>where
VersionVector: Archive,
Archived<VersionVector>: Deserialize<VersionVector, __D>,
Option<SequenceNumber>: Archive,
Archived<Option<SequenceNumber>>: Deserialize<Option<SequenceNumber>, __D>,
impl<__D: Fallible + ?Sized> Deserialize<PeerSyncState, __D> for Archived<PeerSyncState>where
VersionVector: Archive,
Archived<VersionVector>: Deserialize<VersionVector, __D>,
Option<SequenceNumber>: Archive,
Archived<Option<SequenceNumber>>: Deserialize<Option<SequenceNumber>, __D>,
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<PeerSyncState, __D::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<PeerSyncState, __D::Error>
Deserializes using the given deserializer