pub struct ReplicationState {
pub self_id: NodeId,
pub local_vv: VersionVector,
pub peers: HashMap<u32, PeerSyncState>,
}Fields
self_id: NodeIdlocal_vv: VersionVectorpeers: HashMap<u32, PeerSyncState>Trait Implementations
Sourceimpl Archive for ReplicationState
impl Archive for ReplicationState
Sourcetype Archived = ArchivedReplicationState
type Archived = ArchivedReplicationState
The archived representation of this type. Read more
Sourcetype Resolver = ReplicationStateResolver
type Resolver = ReplicationStateResolver
The resolver for this type. It must contain all the additional information from serializing
needed to make the archived type from the normal type.
Sourceimpl Clone for ReplicationState
impl Clone for ReplicationState
Sourcefn clone(&self) -> ReplicationState
fn clone(&self) -> ReplicationState
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ReplicationState
impl Debug for ReplicationState
Sourceimpl Default for ReplicationState
impl Default for ReplicationState
Sourcefn default() -> ReplicationState
fn default() -> ReplicationState
Returns the “default value” for a type. Read more
Sourceimpl<__D: Fallible + ?Sized> Deserialize<ReplicationState, __D> for Archived<ReplicationState>where
NodeId: Archive,
Archived<NodeId>: Deserialize<NodeId, __D>,
VersionVector: Archive,
Archived<VersionVector>: Deserialize<VersionVector, __D>,
HashMap<u32, PeerSyncState>: Archive,
Archived<HashMap<u32, PeerSyncState>>: Deserialize<HashMap<u32, PeerSyncState>, __D>,
impl<__D: Fallible + ?Sized> Deserialize<ReplicationState, __D> for Archived<ReplicationState>where
NodeId: Archive,
Archived<NodeId>: Deserialize<NodeId, __D>,
VersionVector: Archive,
Archived<VersionVector>: Deserialize<VersionVector, __D>,
HashMap<u32, PeerSyncState>: Archive,
Archived<HashMap<u32, PeerSyncState>>: Deserialize<HashMap<u32, PeerSyncState>, __D>,
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<ReplicationState, __D::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<ReplicationState, __D::Error>
Deserializes using the given deserializer
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for ReplicationStatewhere
NodeId: Serialize<__S>,
VersionVector: Serialize<__S>,
HashMap<u32, PeerSyncState>: Serialize<__S>,
impl<__S: Fallible + ?Sized> Serialize<__S> for ReplicationStatewhere
NodeId: Serialize<__S>,
VersionVector: Serialize<__S>,
HashMap<u32, PeerSyncState>: Serialize<__S>,